---
title: <span class="badge object-type-enum"></span> BarGaugeValueMode
---
# <span class="badge object-type-enum"></span> BarGaugeValueMode

Allows for the table cell gauge display type to set the gauge mode.

## Definition

```python
class BarGaugeValueMode(enum.StrEnum):
    """
    Allows for the table cell gauge display type to set the gauge mode.
    """

    COLOR = "color"
    TEXT = "text"
    HIDDEN = "hidden"
```
